Release-Notizen — Lino Tera Benutzerhandbuch

# Release-Notizen

- 19.2.0 (WIP)
- 19.1.0 (2019-01-08)
- 18.12.0 (2018-12-22)
- 18.11.1 (2018-11-30)
- 18.11.0 (2018-11-06)
- 18.10.0 (2018-10-09)
- 18.8.0 (2018-08-16)

Zuletzt aktualisiert am 20.07.2020. Created using Sphinx 3.1.2. Quellcode anzeigen Online Link
Dieses Werk ist lizenziert unter einer Creative Commons Namensnennung - Weitergabe unter gleichen Bedingungen 4.0 International Lizenz.